@@ -12,7 +12,7 @@
 #                                                                                                                      #
 # License:                                                                                                             #
 # ==================================================================================================================== #
-# Copyright 2017-2025 Patrick Lehmann - Bötzingen, Germany                                                             #
+# Copyright 2017-2026 Patrick Lehmann - Bötzingen, Germany                                                             #
 #                                                                                                                      #
 # Licensed under the Apache License, Version 2.0 (the "License");                                                      #
 # you may not use this file except in compliance with the License.                                                     #
@@ -32,7 +32,9 @@
 """
 A common set of missing exceptions in Python.
 
-.. hint:: See :ref:`high-level help <EXECPTION>` for explanations and usage examples.
+.. hint::
+
+   See :ref:`high-level help <EXECPTION>` for explanations and usage examples.
 """
 try:
 	from pyTooling.Decorators import export
