@@ -11,7 +11,7 @@
 #                                                                                                                      #
 # License:                                                                                                             #
 # ==================================================================================================================== #
-# Copyright 2017-2025 Patrick Lehmann - Bötzingen, Germany                                                             #
+# Copyright 2017-2026 Patrick Lehmann - Bötzingen, Germany                                                             #
 #                                                                                                                      #
 # Licensed under the Apache License, Version 2.0 (the "License");                                                      #
 # you may not use this file except in compliance with the License.                                                     #
@@ -31,16 +31,15 @@
 """
 A stopwatch to measure execution times.
 
-.. hint:: See :ref:`high-level help <COMMON/Stopwatch>` for explanations and usage examples.
+.. hint::
+
+   See :ref:`high-level help <COMMON/Stopwatch>` for explanations and usage examples.
 """
 
 from datetime import datetime
-from inspect  import Traceback
 from time     import perf_counter_ns
 from types    import TracebackType
-from typing   import List, Optional as Nullable, Iterator, Tuple, Type
-
-# Python 3.11: use Self if returning the own object: , Self
+from typing   import List, Optional as Nullable, Iterator, Tuple, Type, Self
 
 try:
 	from pyTooling.Decorators  import export, readonly
@@ -83,7 +82,7 @@ class ExcludeContextManager:
 		"""
 		self._stopwatch = stopwatch
 
-	def __enter__(self) -> "ExcludeContextManager":  # TODO: Python 3.11: -> Self:
+	def __enter__(self) -> Self:
 		"""
 		Enter the context and pause the stopwatch.
 
@@ -258,7 +257,7 @@ class Stopwatch(SlottedObject):
 
 		return diff
 
-	def Stop(self):
+	def Stop(self) -> float:
 		"""
 		Stop the stopwatch and return the time delta to the previous stopwatch operation.
 
@@ -294,6 +293,7 @@ class Stopwatch(SlottedObject):
 		self._resumeTime = None
 		self._totalTime =  self._stopTime - self._startTime
 
+		# FIXME: why is this unused?
 		beginEndDiff = self._endTime - self._beginTime
 
 		return diff
@@ -471,7 +471,7 @@ class Stopwatch(SlottedObject):
 
 		return excludeContextManager
 
-	def __enter__(self) -> "Stopwatch":  # TODO: Python 3.11: -> Self:
+	def __enter__(self) -> Self:
 		"""
 		Implementation of the :ref:`context manager protocol's <context-managers>` ``__enter__(...)`` method.
 
@@ -497,7 +497,12 @@ class Stopwatch(SlottedObject):
 
 		return self
 
-	def __exit__(self, exc_type: Type[Exception], exc_val: Exception, exc_tb: Traceback) -> bool:
+	def __exit__(
+		self,
+		exc_type: Nullable[Type[BaseException]] = None,
+		exc_val:  Nullable[BaseException] = None,
+		exc_tb:   Nullable[TracebackType] = None
+	) -> Nullable[bool]:
 		"""
 		Implementation of the :ref:`context manager protocol's <context-managers>` ``__exit__(...)`` method.
 
@@ -531,8 +536,7 @@ class Stopwatch(SlottedObject):
 		else:
 			raise StopwatchException("Stopwatch was not resumed.")
 
-
-	def __len__(self):
+	def __len__(self) -> int:
 		"""
 		Implementation of ``len(...)`` to return the number of split times.
 
@@ -564,7 +568,7 @@ class Stopwatch(SlottedObject):
 		"""
 		return self._splits.__iter__()
 
-	def __str__(self):
+	def __str__(self) -> str:
 		"""
 		Returns the stopwatch's state and its measured time span.
 
