@@ -11,7 +11,7 @@
 #                                                                                                                      #
 # License:                                                                                                             #
 # ==================================================================================================================== #
-# Copyright 2021-2025 Patrick Lehmann - Bötzingen, Germany                                                             #
+# Copyright 2021-2026 Patrick Lehmann - Bötzingen, Germany                                                             #
 #                                                                                                                      #
 # Licensed under the Apache License, Version 2.0 (the "License");                                                      #
 # you may not use this file except in compliance with the License.                                                     #
@@ -140,7 +140,7 @@ class VersionInformation(TestCase):
 
 class DescribePackage(TestCase):
 	@mark.xfail(CurrentPlatform.IsMSYS2Environment, reason="Can fail on MSYS2 environment with Python 3.10+.")
-	def test_PythonPackage(self):
+	def test_PythonPackage(self) -> None:
 		print()
 
 		from pyTooling.Packaging import DescribePythonPackage
@@ -164,7 +164,7 @@ class DescribePackage(TestCase):
 		# TODO: more checks
 
 	@mark.xfail(CurrentPlatform.IsMSYS2Environment, reason="Can fail on MSYS2 environment with Python 3.10+.")
-	def test_PythonPackageFromGitHub(self):
+	def test_PythonPackageFromGitHub(self) -> None:
 		print()
 
 		from pyTooling.Packaging import DescribePythonPackageHostedOnGitHub
